@@ -8,79 +8,79 @@ use Moose;
 use constant{
     BGN_PCGN => {
         #consonants
-        ກ   => 'k',
-        ຂ   => 'kh',
-        ຄ   => 'kh',
-        ງ   => 'ng',
-        ຈ   => 'ch',
-        ສ   => 's',
-        ຊ   => 'x',
-        ຕ   => 't',
-        ຖ   => 'th',
-        ທ   => 'th',
-        ນ   => 'n',
-        ໜ   => 'n',
-        ປ   => 'p',
-        ຜ   => 'ph',
-        ຝ   => 'f',
-        ພ   => 'ph',
-        ຟ   => 'f',
-        ມ   => 'm',
-        ໝ   => 'm',
-        ຢ   => 'y',
-        ຣ   => 'r',
-        ຣ໌  => 'r',
-        ລ   => 'l',
-        ຼ   => 'l',
-        ຫ   => 'h',
-        ຮ   => 'h',
+        'ກ'   => 'k',
+        'ຂ'   => 'kh',
+        'ຄ'   => 'kh',
+        'ງ'   => 'ng',
+        'ຈ'   => 'ch',
+        'ສ'   => 's',
+        'ຊ'   => 'x',
+        'ຕ'   => 't',
+        'ຖ'   => 'th',
+        'ທ'   => 'th',
+        'ນ'   => 'n',
+        'ໜ'   => 'n',
+        'ປ'   => 'p',
+        'ຜ'   => 'ph',
+        'ຝ'   => 'f',
+        'ພ'   => 'ph',
+        'ຟ'   => 'f',
+        'ມ'   => 'm',
+        'ໝ'   => 'm',
+        'ຢ'   => 'y',
+        'ຣ'   => 'r',
+        'ຣ໌'  => 'r',
+        'ລ'   => 'l',
+        'ຼ'   => 'l',
+        'ຫ'   => 'h',
+        'ຮ'   => 'h',
         #ຍ, ຽ, ດ, ບ, ວ, ອ special cases
         #vowels
-        ະ       => 'a',
-        ັ       => 'a',
-        າ       => 'a',
-        ິ       => 'i',
-        ີ       => 'i',
-        ຶ       => 'u',
-        ື       => 'u',
-        ຸ       => 'ou',
-        ູ       => 'ou',
-        ເະ      => 'é',
-        ເັ      => 'é',
-        ເ       => 'é',
-        ແະ      => 'è',
-        ແັ      => 'è',
-        ແ       => 'è',
-        ໂະ      => 'ô',
-        ົ       => 'ô',
-        ໂ       => 'ô',
-        ເາະ     => 'o',
-        ັອ      => 'o',
-        ໍ       => 'o',
-        ອ       => 'o',
-        ເັຽະ    => 'ia',
-        ັຽ      => 'ia',
-        ເັຽ     => 'ia',
-        ຽ       => 'ia',
-        ເັຍະ    => 'ia', #?
-        ັຍ      => 'ia', #?
-        ເັຍ     => 'ia', #?
-        ຍ       => 'ia', #?
-        ເຍ      => 'ia',
-        ເຶອະ    => 'ua',
-        ເຶອ     => 'ua',
-        ເືອ     => 'ua',
-        ເິະ     => 'eu',
-        ເິ      => 'eu',
-        ເີ      => 'eu',
-        ເື      => 'eu',
-        ໄ       => 'ai',
-        ໃ       => 'ai',
-        ເົາ     => 'ao',
-        ຳ       => 'am', #not needed?
-        ໍາ      => 'am', #not needed?
-        ິວ      => 'iou',
-        ີວ      => 'iou',
+        'ະ'       => 'a',
+        'ັ'       => 'a',
+        'າ'       => 'a',
+        'ິ'       => 'i',
+        'ີ'       => 'i',
+        'ຶ'       => 'u',
+        'ື'       => 'u',
+        'ຸ'       => 'ou',
+        'ູ'       => 'ou',
+        'ເະ'      => 'é',
+        'ເັ'      => 'é',
+        'ເ'       => 'é',
+        'ແະ'      => 'è',
+        'ແັ'      => 'è',
+        'ແ'       => 'è',
+        'ໂະ'      => 'ô',
+        'ົ'       => 'ô',
+        'ໂ'       => 'ô',
+        'ເາະ'     => 'o',
+        'ັອ'      => 'o',
+        'ໍ'       => 'o',
+        'ອ'       => 'o',
+        'ເັຽະ'    => 'ia',
+        'ັຽ'      => 'ia',
+        'ເັຽ'     => 'ia',
+        'ຽ'       => 'ia',
+        'ເັຍະ'    => 'ia', #?
+        'ັຍ'      => 'ia', #?
+        'ເັຍ'     => 'ia', #?
+        'ຍ'       => 'ia', #?
+        'ເຍ'      => 'ia',
+        'ເຶອະ'    => 'ua',
+        'ເຶອ'     => 'ua',
+        'ເືອ'     => 'ua',
+        'ເິະ'     => 'eu',
+        'ເິ'      => 'eu',
+        'ເີ'      => 'eu',
+        'ເື'      => 'eu',
+        'ໄ'       => 'ai',
+        'ໃ'       => 'ai',
+        'ເົາ'     => 'ao',
+        'ຳ'       => 'am', #not needed?
+        'ໍາ'      => 'am', #not needed?
+        'ິວ'      => 'iou',
+        'ີວ'      => 'iou',
         # special case: ົວະ, ັວ, ົວ, ວ
     },
 };
@@ -91,11 +91,11 @@ Lingua::LO::Romanize::Syllable - Class for syllables, used by Lingua::LO::Romani
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 has 'syllable_str' => (
     is          => 'ro',
